@@ -70,10 +70,13 @@ void importflashcard::on_pushImport_clicked()
     #endif
     QFile file(ui->plainFileName);
 
-    createDatabase();
-    purgeDatabase();
+    ui->lblImporting->setText("Importing...");
 
+//    createDatabase();
+//    purgeDatabase();
+    qApp->processEvents();
     this->importdelimited(ui->plainFileName->toPlainText());
+    ui->lblImporting->setText("");
 
     return;
 
@@ -477,16 +480,25 @@ int importflashcard::createCourse(QString coursename,
      }
     iCourseID++;
 
+/*
+    if (!qry.exec("CREATE TABLE IF NOT EXISTS courses "
+                  "(name VARCHAR(40), courseid SMALLINT,"
+                  "side1 VARCHAR(20), side2 VARCHAR(20), side3 VARCHAR(20), side4 VARCHAR(20), "
+                  "showside1 SMALLINT, showside2 SMALLINT, showside3 SMALLINT, showside4 SMALLINT, "
+                  "sortby SMALLINT, selectby SMALLINT)"))
+*/
+
 //    qry.prepare("INSERT INTO courses (name, ROWID, side1, side2, side3, side4) VALUES"
 //                "(:coursename, :courseid, :side1, :side2, :side3, :side4)");
-    qry2.prepare("INSERT INTO courses (name, courseid, side1, side2, side3, side4) VALUES "
-                "(:coursename, :courseid, :side1, :side2, :side3, :side4)");
+    qry2.prepare("INSERT INTO courses (name, courseid, side1, side2, side3, side4, showside1) VALUES "
+                 "(:coursename, :courseid, :side1, :side2, :side3, :side4, :showside1)");
     qry2.bindValue(":coursename", coursename);
     qry2.bindValue(":courseid", iCourseID);
     qry2.bindValue(":side1", sSide1);
     qry2.bindValue(":side2", sSide2);
     qry2.bindValue(":side3", sSide3);
     qry2.bindValue(":side4", sSide4);
+    qry2.bindValue(":showside1", 1);
     if (!qry2.exec())
     {
         qDebug() << qry2.lastQuery();
@@ -599,7 +611,22 @@ void importflashcard::createDatabase()
 
     if (!qry.exec("CREATE TABLE IF NOT EXISTS words "
         "(side1 VARCHAR(80), side2 VARCHAR(40), side3 VARCHAR(10), "
-        "side4 VARCHAR(10))"))
+        "side4 VARCHAR(10), audio VARCHAR(80), image VARCHAR(80), video VARCHAR(80))"))
+    {
+        qDebug() << qry.lastQuery();
+        qDebug() << qry.lastError();
+    }
+
+    if (!qry.exec("CREATE TABLE IF NOT EXISTS settings "
+        "(courseid INT, chapterid INT, username VARCHAR(80))"))
+    {
+        qDebug() << qry.lastQuery();
+        qDebug() << qry.lastError();
+    }
+
+    qry.prepare("INSERT INTO settings (courseid, chapterid) VALUES "
+                "(1, 1)");
+    if (!qry.exec())
     {
         qDebug() << qry.lastQuery();
         qDebug() << qry.lastError();
@@ -633,6 +660,12 @@ void importflashcard::purgeDatabase()
 {
     QSqlQuery qry;
 
+    if (!qry.exec("DELETE FROM settings"))
+    {
+        qDebug() << qry.lastQuery();
+        qDebug() << qry.lastError();
+    }
+
     if (!qry.exec("DELETE FROM words"))
     {
         qDebug() << qry.lastQuery();
