@@ -18,7 +18,7 @@
 // 6. Add GPS
 // 7. Add editing capabilities
 // 8. Add other language (French? Swedish? Other?)
-// 9. Display learning % on the chapters
+// x 9. Display learning % on the chapters
 // 10. Add animations
 // 11. Add download of databases from web
 // 12. Add audio
@@ -65,9 +65,15 @@ int qiLessonID=1;
 int qiSortBy=1;
 int qiSelectBy=1;
 QString qsLessonName;
-QString sside3;
 QString sside1;
 QString sside2;
+QString sside3;
+//bool bshowSide1;
+//bool bshowSide2;
+//bool bshowSide3;
+int iChapterID;
+int iCourseID;
+
 QString sMandarin;
 Settings *dlgSettings;
 importflashcard *dlgImportFlashcards;
@@ -83,8 +89,6 @@ MainWindow::MainWindow(QWidget *parent)
 
     QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE");
 
-
-
     #ifdef Q_OS_LINUX
 		// NOTE: We have to store database file into user home folder in Linux
 		QString path(QDir::home().path());
@@ -105,46 +109,110 @@ MainWindow::MainWindow(QWidget *parent)
     dlgImportFlashcards = new importflashcard;
 //    db.setDatabaseName("qteachme.db");
 
-    if (!db.open())
+    if ((!db.open()) || (db.tables().count() == 0))
     {
         qDebug() << "Failed to connect";
         qDebug() << db.lastError();
 //        qFatal ("Failed to connect");
         //In case there is no database, we need to create a new one by importing some files.
+        dlgImportFlashcards->createDatabase();
         dlgImportFlashcards->show();
         if (dlgImportFlashcards->exec() == QDialog::Accepted)
         {
         }
+        SettingsMenu();
 
     }
 
+    QSqlQuery qry;
+
+
+// For the time being, always start with CourseID=1 and ChapterID=1
+
+    qry.prepare("SELECT courseid, chapterid FROM settings");
+
+    if (!qry.exec())
+    {
+        qDebug() << qry.lastQuery();
+        qDebug() << qry.lastError();
+    }
+
+    qry.next();
+
+    iCourseID = qry.value(0).toInt();
+    qDebug() << "iCourseID" << iCourseID;
+    iChapterID = qry.value(1).toInt();
+    qDebug() << "iChapterID" << iChapterID;
+
+//    iCourseID = 1;
+//    iChapterID = 1;
+
+
+    qry.prepare("SELECT name "
+                "FROM chapters "
+                "WHERE rowid=:chapterid");
+
+    qry.bindValue(":chapterid", iChapterID);
+    qDebug() << "iChapterID" << iChapterID;
+    if (!qry.exec())
+    {
+        qDebug() << qry.lastQuery();
+        qDebug() << qry.lastError();
+    }
+    qry.next();
+
+    qsLessonName=qry.value(0).toString();
+    qDebug() << "qsLessonName" << qsLessonName;
+
+    qry.prepare("SELECT showside1, showside2, showside3, showside4, "
+                "sortby, selectby "
+                "FROM courses "
+                "WHERE courseid=:courseid");
+
+    qry.bindValue(":courseid", iCourseID);
+    qDebug() << "iCourseID" << iCourseID;
+    if (!qry.exec())
+    {
+        qDebug() << qry.lastQuery();
+        qDebug() << qry.lastError();
+    }
+
+    qry.next();
+
+    dlgSettings->setshowSide1(qry.value(0).toBool());
+    qDebug() << dlgSettings->showSide1();
+    dlgSettings->setshowSide2(qry.value(1).toBool());
+    qDebug() << dlgSettings->showSide2();
+    dlgSettings->setshowSide3(qry.value(2).toBool());
+    qDebug() << dlgSettings->showSide3();
 
-//    connect(this, SIGNAL(SettingsMenu()), ui->action_Settings, SLOT(activated()));
     connect(this, SIGNAL(side3Changed(QString)), ui->txtSide3, SLOT(setText(QString)));
     connect(this, SIGNAL(side2Changed(QString)), ui->txtSide2, SLOT(setText(QString)));
     connect(this, SIGNAL(side1Changed(QString)), ui->txtSide1, SLOT(setText(QString)));
-        ui->txtSide2->viewport()->setAutoFillBackground(false);
-        ui->txtSide3->viewport()->setAutoFillBackground(false);
-        ui->txtSide1->viewport()->setAutoFillBackground(false);
+    ui->txtSide2->viewport()->setAutoFillBackground(false);
+    ui->txtSide3->viewport()->setAutoFillBackground(false);
+    ui->txtSide1->viewport()->setAutoFillBackground(false);
 	
-        //    connect(this, SIGNAL(mandarinChanged(QString)), ui->txtSide1, SLOT(setText(QString)));
-
     if (db.tables().count()>0)
     {
         this->handleSelection(0);
     }
 
-    ui->pbSettings->setVisible(false);
-    ui->pushButton_6->setVisible(false);
+//    ui->pbSettings->setVisible(false);
+//    ui->pushButton_6->setVisible(false);
     ui->txtSide3->setAlignment(Qt::AlignCenter);
     ui->txtSide2->setAlignment(Qt::AlignCenter);
     ui->txtSide1->setAlignment(Qt::AlignCenter);
     ui->pbBad->setVisible(false);
     ui->pbGood->setVisible(false);
     ui->pbOK->setVisible(false);
-    ui->txtSide1->setVisible(true);
-    ui->txtSide2->setVisible(false);
-    ui->txtSide3->setVisible(false);
+    ui->pbShow->setVisible(true);
+    ui->txtSide1->setVisible(dlgSettings->showSide1());
+    qDebug() << dlgSettings->showSide1();
+    ui->txtSide2->setVisible(dlgSettings->showSide2());
+    qDebug() << dlgSettings->showSide2();
+    ui->txtSide3->setVisible(dlgSettings->showSide3());
+    qDebug() << dlgSettings->showSide3();
 
 //    QPalette pal = widget.palette();
     QPalette pal = this->palette();
@@ -154,20 +222,18 @@ MainWindow::MainWindow(QWidget *parent)
     QMenuBar *menuBar=new QMenuBar();
     QAction *showSettings=new QAction("Settings",this);
     menuBar->addAction(showSettings);
-    connect(showSettings,SIGNAL(triggered()),ui->pbSettings, SLOT(click()));
-//    QAction *showLoadDatabase=new QAction("Load Database",this);
-//    menuBar->addAction(showLoadDatabase);
-//    connect(showLoadDatabase,SIGNAL(triggered()),ui->pushButton_6,SLOT(click()));
+    connect(showSettings,SIGNAL(triggered()),this, SLOT(SettingsMenu()));
     QAction *showImportFlashcards=new QAction("Import Flashcards",this);
     menuBar->addAction(showImportFlashcards);
     connect(showImportFlashcards,SIGNAL(triggered()),this,SLOT(showImportFlashcards()));
     QAction *showAbout=new QAction("About",this);
     menuBar->addAction(showAbout);
     connect(showAbout, SIGNAL(triggered()), this, SLOT(showAbout()));
+    QAction *showPurge=new QAction("Purge All Flashcards",this);
+    menuBar->addAction(showPurge);
+    connect(showPurge,SIGNAL(triggered()),this, SLOT(purgeAll()));
     setMenuBar(menuBar);
 
-
-
     ui->progressBarWord->setStyle(new QPlastiqueStyle);
     ui->progressBarCourse->setStyle(new QPlastiqueStyle);
 }
@@ -177,6 +243,8 @@ MainWindow::~MainWindow()
     delete ui;
 }
 
+
+/*
 void MainWindow::on_pushButton_6_clicked()
 {
     int iChapterID = 1;
@@ -246,7 +314,7 @@ void MainWindow::on_pushButton_6_clicked()
     if (!qry.exec("CREATE TABLE IF NOT EXISTS courses "
                   "(name VARCHAR(40),"
                   "lang1 VARCHAR(20), lang2 VARCHAR(20), lang3 VARCHAR(20), lang4 VARCHAR(20), "
-                  "showlang1 SMALLINT, showlang2 SMALLINT, showlang3 SMALLINT, showlang4 SMALLINT, "
+                  "showSide1 SMALLINT, showSide2 SMALLINT, showSide3 SMALLINT, showSide4 SMALLINT, "
                   "sortby SMALLINT, selectby SMALLINT)"))
     {
         qDebug() << qry.lastQuery();
@@ -272,7 +340,7 @@ void MainWindow::on_pushButton_6_clicked()
         qDebug() << qry.lastError();
     }
 
-/*
+
     qry.prepare("INSERT INTO courses (name, ROWID) VALUES ('HSK Level 1', 1)");
     if (!qry.exec())
     {
@@ -300,7 +368,7 @@ void MainWindow::on_pushButton_6_clicked()
         qDebug() << qry.lastQuery();
         qDebug() << qry.lastError();
     }
-*/
+
     if (!qry.exec("CREATE TABLE IF NOT EXISTS chapterwords (wordid SMALLINT, lessonid SMALLINT, score SMALLINT, scoredelta SMALLINT)"))
     {
         qDebug() << qry.lastQuery();
@@ -405,12 +473,12 @@ void MainWindow::on_pushButton_6_clicked()
                     qDebug() << "Level  : " << element.text().toInt();
                     qDebug() << "Course : " << iCourseID;
                     qDebug() << "Chapter: " << iChapterID;
-/*
+
                     if (element.text().toInt()!=iCourseID)
                     {
                         iChapterID++;
                     }
-*/
+
                 }
 
                 qry2.bindValue(":lessonid", iChapterID);
@@ -513,12 +581,14 @@ void MainWindow::on_pushButton_6_clicked()
 //    int ret = msgBox.exec();
 
 }
+*/
 
+/*
 void MainWindow::SettingsMenu()
 {
     qDebug() << "Settings Menu";
 }
-
+*/
 
 void MainWindow::setSide3(const QString &text)
 {
@@ -558,7 +628,6 @@ void MainWindow::setMandarin(const QString &text)
 }
 
 
-//void handleSelection(MainWindow *ui)
 void MainWindow::handleSelection(const int iChangeScore)
 {
 
@@ -571,30 +640,30 @@ void MainWindow::handleSelection(const int iChangeScore)
     if (qiWordID>0)
     {
 
-		#ifdef Q_OS_LINUX
-			// NOTE: We have to store database file into user home folder in Linux
-			QString path(QDir::home().path());
-			path.append(QDir::separator()).append("audio").append(QDir::separator()).append("test.aac");
-			path = QDir::toNativeSeparators(path);
-			qDebug() << "Audio path:" << path;
-		#else
-			// NOTE: File exists in the application private folder, in Symbian Qt implementation
-			QString path( "./audio/test.aac" );
-		#endif
+        #ifdef Q_OS_LINUX
+                // NOTE: We have to store database file into user home folder in Linux
+                QString path(QDir::home().path());
+                path.append(QDir::separator()).append("audio").append(QDir::separator()).append("test.aac");
+                path = QDir::toNativeSeparators(path);
+                qDebug() << "Audio path:" << path;
+        #else
+                // NOTE: File exists in the application private folder, in Symbian Qt implementation
+                QString path( "./audio/test.aac" );
+        #endif
 
-		QFile audiofile(path);
+        QFile audiofile(path);
 
-		if (audiofile.exists())
-		{
+        if (audiofile.exists())
+        {
 
 //		mediaObject = new Phonon::MediaObject();
 //		Phonon::MediaObject *mediaObject =
 //				 Phonon::createPlayer(Phonon::MusicCategory,
 //									  Phonon::MediaSource(path));
 //			 mediaObject->play();
-		}
+        }
 
-		 if (iChangeScore<0)
+         if (iChangeScore<0)
         {
             if (qiScoreDelta<=0)
             {
@@ -650,7 +719,7 @@ void MainWindow::handleSelection(const int iChangeScore)
         ui->lblScore->setAlignment(Qt::AlignRight);
 
 //      THIS SHOULD ALSO INCLUDE LESSONID!
-        qry.prepare("UPDATE chapterwords SET score=:score, scoredelta=:scoredelta WHERE wordid=:wordid");
+        qry.prepare("UPDATE chapterwords SET score=:score, scoredelta=:scoredelta WHERE wordid=:wordid ");
 
         qry.bindValue(":score", qiScore);
         qry.bindValue(":scoredelta", qiScoreDelta);
@@ -677,9 +746,18 @@ void MainWindow::handleSelection(const int iChangeScore)
 	//Settings window isn't fixed.
 //	qiSortBy = 3;
 	
+    if (qiSelectBy == 1) //All
+    {
+        selectBy = "";
+    }
+    else if (qiSelectBy == 2) //Not learned
+    {
+        selectBy = " AND score <100 ";
+    }
+
     if (qiSortBy == 1) //Random
     {
-        sortOrder = "ORDER BY RANDOM() LIMIT 1";
+        sortOrder = " ORDER BY RANDOM() LIMIT 1 ";
     }
     else if (qiSortBy == 2) //Alphabetic
     {
@@ -687,16 +765,7 @@ void MainWindow::handleSelection(const int iChangeScore)
     }
     else if (qiSortBy == 3) //Difficulty
     {
-        sortOrder = "ORDER BY score ASC, RANDOM() LIMIT 1";
-    }
-
-    if (qiSelectBy == 1) //All
-    {
-        selectBy = "";
-    }
-    else if (qiSelectBy == 2) //Not learned
-    {
-        selectBy = "AND score <100 ";
+        sortOrder = " ORDER BY score ASC, RANDOM() LIMIT 1 ";
     }
 
     qry2.prepare("SELECT lessonid, wordid, score, scoredelta "
@@ -705,7 +774,6 @@ void MainWindow::handleSelection(const int iChangeScore)
                  "AND lessonid = :lessonid "
                  + selectBy
                  + sortOrder);
-//                 "ORDER BY score ASC, RANDOM() LIMIT 1");
     qry2.bindValue(":wordid", qiWordID);
     qry2.bindValue(":lessonid", qiLessonID);
     if (!qry2.exec())
@@ -724,7 +792,6 @@ void MainWindow::handleSelection(const int iChangeScore)
     qDebug() << qiScoreDelta;
     rec = qry2.record();
 
-
     if (!qry.prepare("SELECT side1, side2, side3 "
                      "FROM words "
                      "WHERE rowid=:wordid"))
@@ -737,7 +804,6 @@ void MainWindow::handleSelection(const int iChangeScore)
     qDebug() << "qiWordID=" << qiWordID;
     qry.bindValue(":wordid", qry2.value(1).toInt());
 
-
     if (!qry.exec())
     {
         qDebug() << qry.lastQuery();
@@ -774,12 +840,16 @@ void MainWindow::handleSelection(const int iChangeScore)
     ui->txtSide3->setAlignment(Qt::AlignCenter);
     ui->txtSide2->setAlignment(Qt::AlignCenter);
     ui->txtSide1->setAlignment(Qt::AlignCenter);
-    ui->pbBad->setVisible(!ui->pbBad->isVisible());
-    ui->pbGood->setVisible(!ui->pbGood->isVisible());
-    ui->pbOK->setVisible(!ui->pbOK->isVisible());
-    ui->pbShow->setVisible(!ui->pbOK->isVisible());
-    ui->txtSide2->setVisible(!ui->txtSide2->isVisible());
-    ui->txtSide3->setVisible(!ui->txtSide3->isVisible());
+    ui->pbBad->setVisible(false);
+    ui->pbGood->setVisible(false);
+    ui->pbOK->setVisible(false);
+    ui->pbShow->setVisible(true);
+    ui->txtSide1->setVisible(dlgSettings->showSide1());//dlgSettings->showSide1());
+    qDebug() << dlgSettings->showSide1();
+    ui->txtSide2->setVisible(dlgSettings->showSide2());//dlgSettings->showSide2());
+    qDebug() << dlgSettings->showSide2();
+    ui->txtSide3->setVisible(dlgSettings->showSide3());//dlgSettings->showSide3());
+    qDebug() << dlgSettings->showSide3();
     ui->progressBarWord->setValue(qiScore);
 
     QPalette pal = ui->progressBarWord->palette();
@@ -820,6 +890,7 @@ void MainWindow::handleSelection(const int iChangeScore)
         qDebug() << qry2.lastError();
     }
     qry2.next();
+
     int iCount = qry2.value(0).toInt();
     if (iCount != 0 )
     {
@@ -849,22 +920,29 @@ void MainWindow::handleSelection(const int iChangeScore)
     }
     ui->progressBarCourse->setPalette(pal);
 
-
-
     qApp->processEvents();
 }
 
-void MainWindow::on_pbSettings_clicked()
+void MainWindow::purgeAll()
+{
+    dlgImportFlashcards->purgeDatabase();
+}
+
+
+//void MainWindow::on_pbSettings_clicked()
+void MainWindow::SettingsMenu()
 {
 
-    int iCourseID;
+//    int iCourseID;
 
     QSqlQuery qry;
+    QString courseName;
+    QString chapterName;
 
     //Launch the Settings Window
     dlgSettings->show();
 
-    qry.prepare("SELECT rowid, * "
+    qry.prepare("SELECT rowid, name "
                  "FROM courses");
 
     if (!qry.exec())
@@ -875,14 +953,31 @@ void MainWindow::on_pbSettings_clicked()
 
     }
     qry.next();
-    iCourseID=qry.value(0).toInt();
+
     dlgSettings->lstCourse->clear();
     while (qry.isValid())
     {
         dlgSettings->lstCourse->addItem(qry.value(1).toString());
+        if (iCourseID == qry.value(0).toInt())
+        {
+            courseName=qry.value(1).toString();
+        }
         qry.next();
     }
 
+    //This should trigger the selection of chapters.
+    dlgSettings->lstCourse->setCurrentIndex(dlgSettings->lstCourse->findText(courseName));
+
+    qApp->processEvents();
+
+    chapterName = courseName + ": Chapter " + QString::number(qiLessonID,10);
+    qDebug() << "chapterName" << chapterName;
+    int index;
+    index = dlgSettings->listChapter->findText(chapterName);
+    qDebug() << "index" << index;
+    dlgSettings->listChapter->setCurrentIndex(index);
+
+/*
     qry.prepare("SELECT * "
                 "FROM chapters "
                 "WHERE courseid=:courseid");
@@ -908,38 +1003,53 @@ void MainWindow::on_pbSettings_clicked()
         dlgSettings->listChapter->addItem(qry.value(0).toString());
         qry.next();
     }
+*/
 
     if (dlgSettings->exec() == QDialog::Accepted)
     {
         QSqlQuery qry;
 
         qry.prepare("UPDATE courses SET "
-                    "showLang1=:showLang1, showLang2=:showLang2, showLang3=:showLang3, showLang4=:showLang4, "
-                    "sortBy=:sortBy, selectBy=:selectBy "
-                    "WHERE rowid =:courseid");
+                    "showside1=:showSide1, showside2=:showSide2, showside3=:showSide3, showside4=:showSide4, "
+                    "sortby=:sortBy, selectby=:selectBy "
+                    "WHERE courseid=:courseid");
 
-        qry.bindValue(":showLang1", dlgSettings->showLang1());
-        qry.bindValue(":showLang2", dlgSettings->showLang2());
-        qry.bindValue(":showLang3", dlgSettings->showLang3());
-        qry.bindValue(":showLang4", dlgSettings->showLang4());
+        qry.bindValue(":showSide1", dlgSettings->showSide1());
+//        qDebug << "dlgSettings->showSide1()" << dlgSettings->showSide1();
+        qry.bindValue(":showSide2", dlgSettings->showSide2());
+//        qDebug << "dlgSettings->showSide2()" << dlgSettings->showSide2();
+        qry.bindValue(":showSide3", dlgSettings->showSide3());
+//        qDebug << "dlgSettings->showSide3()" << dlgSettings->showSide3();
+        qry.bindValue(":showSide4", dlgSettings->showSide4());
+ //       qDebug << "dlgSettings->showSide4()" << dlgSettings->showSide4();
         qiSortBy = dlgSettings->sortBy();
         qry.bindValue(":sortBy", qiSortBy);
         qDebug() << "SortBy: " << qiSortBy;
         qiSelectBy = dlgSettings->selectBy();
         qry.bindValue(":selectBy", qiSelectBy);
         qDebug() << "SelectBy: " << qiSelectBy;
-//        dlgSettings->listChapter->itemText()
-//        qDebug() << "listChapter.selected.text : " << dlgSettings->listChapter->selectedItems().first()->text();
-        qDebug() << "listChapter.selected.text : " << dlgSettings->listChapter->currentText();
-        qDebug() << "lstCourse.selected.text " << dlgSettings->lstCourse->currentText();
+//        qDebug() << "listChapter.selected.text : " << dlgSettings->listChapter->currentText();
+//        qDebug() << "lstCourse.selected.text " << dlgSettings->lstCourse->currentText();
 //  HARDCODED
-        qry.bindValue(":courseid", 1);
+        qDebug() << "dlgSettings->courseID()" << dlgSettings->courseID();
+        qry.bindValue(":courseid", dlgSettings->courseID());
+
+        QMapIterator<QString, QVariant> i(qry.boundValues());
+        while (i.hasNext()) {
+            i.next();
+            qDebug() << i.key().toAscii().data() << ": "
+                 << i.value().toString().toAscii().data() << endl;
+        }
+
         if (!qry.exec())
         {
             qDebug() << qry.lastQuery();
             qDebug() << qry.lastError();
         }
 
+        qsLessonName=dlgSettings->listChapter->currentText();
+
+        /*
         qry.prepare("SELECT rowid "
                     "FROM chapters "
                     "WHERE name=:name");
@@ -956,6 +1066,8 @@ void MainWindow::on_pbSettings_clicked()
         qDebug() << "LessonID : " << qry.value(0);
         qDebug() << "Name : " << dlgSettings->listChapter->currentText();
         qiLessonID=qry.value(0).toInt();
+ */
+        qiLessonID=dlgSettings->chapterID();
 
         this->handleSelection(0);
     }
@@ -977,12 +1089,13 @@ void MainWindow::on_pbGood_clicked()
 
 void MainWindow::on_pbShow_clicked()
 {
-    ui->pbShow->setVisible(!ui->pbShow->isVisible());
-    ui->pbBad->setVisible(!ui->pbBad->isVisible());
-    ui->pbGood->setVisible(!ui->pbGood->isVisible());
-    ui->pbOK->setVisible(!ui->pbOK->isVisible());
-    ui->txtSide2->setVisible(!ui->txtSide2->isVisible());
-    ui->txtSide3->setVisible(!ui->txtSide3->isVisible());
+    ui->pbShow->setVisible(false);
+    ui->pbBad->setVisible(true);
+    ui->pbGood->setVisible(true);
+    ui->pbOK->setVisible(true);
+    ui->txtSide1->setVisible(true);
+    ui->txtSide2->setVisible(true);
+    ui->txtSide3->setVisible(true);
 }
 
 void MainWindow::showAbout()
@@ -994,7 +1107,7 @@ void MainWindow::showAbout()
     message.append("Qteachme");
     message.append("-");
 //    version = version.setNum(APP_VERSION);
-    version = "0.1";
+    version = "0.1.1";
     message.append(version);
     message.append("\n by ");
 //    message.append(AUTHOR);
