@@ -40,13 +40,14 @@ public slots:
     void SettingsMenu();
     void showAbout();
     void showImportFlashcards();
+    void purgeAll();
 
 private slots:
     void on_pbBad_clicked();
     void on_pbOK_clicked();
     void on_pbGood_clicked();
-    void on_pbSettings_clicked();
-    void on_pushButton_6_clicked();
+//    void on_pbSettings_clicked();
+//    void on_pushButton_6_clicked();
     void on_pbShow_clicked();
 
 signals:
